@@ -10,7 +10,7 @@ use Readonly;
 Readonly::Array our @EXPORT_OK => qw(check_array_object check_isa
 	check_number check_number_of_items check_required);
 
-our $VERSION = 0.02;
+our $VERSION = 0.03;
 
 sub check_array_object {
 	my ($self, $key, $class, $class_name) = @_;
@@ -49,7 +49,7 @@ sub check_number {
 		return;
 	}
 
-	if ($self->{$key} !~ m/^-?\d+$/ms) {
+	if ($self->{$key} !~ m/^[-+]?\d+(\.\d+)?$/ms) {
 		err "Parameter '$key' must be a number.";
 	}
 
@@ -376,6 +376,6 @@ BSD 2-Clause License
 
 =head1 VERSION
 
-0.02
+0.03
 
 =cut
